<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>AsciiFile</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="35"/>
        <location filename="../asciifile/asciifile.cpp" line="41"/>
        <source>Read ascii points</source>
        <translation>讀取ASCII點</translation>
    </message>
</context>
<context>
    <name>ImportShp</name>
    <message>
        <location filename="../importshp/importshp.cpp" line="40"/>
        <source>Import ESRI Shapefile</source>
        <translation>導入ESRI外形文件</translation>
    </message>
</context>
<context>
    <name>LC_Align</name>
    <message>
        <location filename="../align/align.cpp" line="20"/>
        <location filename="../align/align.cpp" line="27"/>
        <source>Align</source>
        <translation>對齊</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="40"/>
        <source>first base point:</source>
        <translation>第一基點</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="42"/>
        <source>first target point:</source>
        <translation>第一個目標點</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="44"/>
        <source>second base point:</source>
        <translation>第二基點</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="46"/>
        <source>second target point:</source>
        <translation>第二個目標點</translation>
    </message>
</context>
<context>
    <name>LC_Gear</name>
    <message>
        <location filename="../gear/gear.cpp" line="33"/>
        <source>Gear creation plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="40"/>
        <source>Gear plugin</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LC_List</name>
    <message>
        <location filename="../list/list.cpp" line="23"/>
        <location filename="../list/list.cpp" line="30"/>
        <source>List entities</source>
        <translation>列出實體</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="46"/>
        <source>n</source>
        <translation>n</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="60"/>
        <source>Empty Entity</source>
        <translation>空實體</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="67"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="67"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="77"/>
        <source>Layer</source>
        <translation>圖層</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="79"/>
        <source>Color</source>
        <translation>顏色</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="80"/>
        <source>Line type</source>
        <translation>線條類型</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="81"/>
        <source>Line thickness</source>
        <translation>線條粗細</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="82"/>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="88"/>
        <source>POINT</source>
        <translation>點</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="89"/>
        <location filename="../list/list.cpp" line="218"/>
        <source>in point</source>
        <translation>於點</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="94"/>
        <source>LINE</source>
        <translation>線段</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="99"/>
        <source>from point</source>
        <translation>從點</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="102"/>
        <source>to point</source>
        <translation>至點</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="107"/>
        <location filename="../list/list.cpp" line="131"/>
        <source>length</source>
        <translation>長度</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="112"/>
        <source>Angle in XY plane</source>
        <translation>平面角度</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="113"/>
        <source>Inc.</source>
        <translation>偏移量</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="118"/>
        <source>ARC</source>
        <translation>弧</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="119"/>
        <location filename="../list/list.cpp" line="135"/>
        <location filename="../list/list.cpp" line="145"/>
        <source>center point</source>
        <translation>中心點</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="125"/>
        <location filename="../list/list.cpp" line="139"/>
        <location filename="../list/list.cpp" line="222"/>
        <source>radius</source>
        <translation>半徑</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="126"/>
        <source>initial angle</source>
        <translation>初始角</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="127"/>
        <source>final angle</source>
        <translation>終止角度</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="134"/>
        <source>CIRCLE</source>
        <translation>圓</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="140"/>
        <source>circumference</source>
        <translation>圓周</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="141"/>
        <source>area</source>
        <translation>面積</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="144"/>
        <source>ELLIPSE</source>
        <translation>橢圓</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="148"/>
        <source>major axis</source>
        <translation>長軸</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="166"/>
        <source>CONSTRUCTIONLINE</source>
        <translation>輔助線</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="169"/>
        <source>OVERLAYBOX</source>
        <translation>疊加框</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="172"/>
        <source>SOLID</source>
        <translation>實心</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="176"/>
        <source>MTEXT</source>
        <translation>多行文本</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="179"/>
        <source>TEXT</source>
        <translation>文本</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="182"/>
        <source>INSERT</source>
        <translation>鑲嵌</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="185"/>
        <source>Name</source>
        <translation>名</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="187"/>
        <source>Insertion point</source>
        <translation>插入點</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="190"/>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="193"/>
        <source>Rotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="199"/>
        <source>Columns/Rows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="203"/>
        <source>Column/Row Spacing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="210"/>
        <source>POLYLINE</source>
        <translation>折線</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="211"/>
        <source>Closed</source>
        <translation>閉合</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="212"/>
        <source>No</source>
        <translation>不</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="212"/>
        <source>Yes</source>
        <translation>是</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="213"/>
        <source>Vertices</source>
        <translation>節點</translation>
    </message>
    <message>
        <source>curvature</source>
        <translation type="obsolete">曲率</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="227"/>
        <source>IMAGE</source>
        <translation>圖片</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="230"/>
        <source>SPLINE</source>
        <translation>樣條曲線</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="233"/>
        <source>SPLINEPOINTS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="236"/>
        <source>HATCH</source>
        <translation>陰影</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="239"/>
        <source>DIMLEADER</source>
        <translation>導出標註</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="242"/>
        <source>DIMALIGNED</source>
        <translation>Duìqí biāozhù對齊標註</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="245"/>
        <source>DIMLINEAR</source>
        <translation>線性標註</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="248"/>
        <source>DIMRADIAL</source>
        <translation>半徑標註</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="251"/>
        <source>DIMDIAMETRIC</source>
        <translation>直徑標註</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="254"/>
        <source>DIMANGULAR</source>
        <translation>角度标注</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="257"/>
        <source>UNKNOWN</source>
        <translation>未知</translation>
    </message>
</context>
<context>
    <name>LC_SameProp</name>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="21"/>
        <location filename="../sameprop/sameprop.cpp" line="28"/>
        <source>Same properties</source>
        <translation>相同屬性</translation>
    </message>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="41"/>
        <source>select original entity:</source>
        <translation>選擇原始實體：</translation>
    </message>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="43"/>
        <source>select entities to change</source>
        <translation>選擇需要改變的實體</translation>
    </message>
</context>
<context>
    <name>LC_Sample</name>
    <message>
        <location filename="../sample/sample.cpp" line="26"/>
        <location filename="../sample/sample.cpp" line="33"/>
        <source>Sample plugin</source>
        <translation>示例插件</translation>
    </message>
</context>
<context>
    <name>PicFile</name>
    <message>
        <location filename="../picfile/picfile.cpp" line="36"/>
        <source>Read PIC file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="42"/>
        <source>import PIC file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dibPunto</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="229"/>
        <source>Read ascii points</source>
        <translation>讀取ASCII點</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="235"/>
        <source>File...</source>
        <translation>文檔...</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="242"/>
        <source>Format:</source>
        <translation>格式：</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="244"/>
        <source>Space Separator</source>
        <translation>空格分隔符</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="244"/>
        <source>Tab Separator</source>
        <translation>Tab鍵分隔符</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="244"/>
        <source>Comma Separator</source>
        <translation>逗號分隔符</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="244"/>
        <source>Space in Columns</source>
        <translation>列包含空格</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="244"/>
        <source>*.odb for Psion 2</source>
        <translation> *.odb Psion 2 格式</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="246"/>
        <source>Connect points</source>
        <translation>連接點</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="254"/>
        <source>2D Point</source>
        <translation>2維點</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="254"/>
        <source>Draw 2D Point</source>
        <translation>繪製2維點</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="255"/>
        <source>3D Point</source>
        <translation>繪製3維點</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="255"/>
        <source>Draw 3D Point</source>
        <translation>點編號</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="256"/>
        <source>Point Number</source>
        <translation>點編號</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="256"/>
        <source>Draw point number</source>
        <translation>繪製點編號</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="257"/>
        <source>Point Elevation</source>
        <translation>點抬高</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="257"/>
        <source>Draw point elevation</source>
        <translation>繪製點抬高</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="258"/>
        <source>Point Code</source>
        <translation>點編碼</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="258"/>
        <source>Draw point code</source>
        <translation>繪製點編碼</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="272"/>
        <source>Accept</source>
        <translation>接受</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="277"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="307"/>
        <source>Select file</source>
        <translation>選擇文檔</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="314"/>
        <source>Point 2D layer is empty</source>
        <translation>點2D層為空</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="317"/>
        <source>Point 3D layer is empty</source>
        <translation>點3D層為空</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="320"/>
        <source>Point elevation layer is empty</source>
        <translation>點抬高層為空</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="321"/>
        <source>Point elevation height is empty</source>
        <translation>點抬高為空</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="322"/>
        <source>Point elevation separation is empty</source>
        <translation>點抬高分隔為空</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="325"/>
        <source>Point number layer is empty</source>
        <translation>點編號層為空</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="326"/>
        <source>Point number height is empty</source>
        <translation>點編號高度為空</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="327"/>
        <source>Point number separation is empty</source>
        <translation>點編號分隔為空</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="330"/>
        <source>Point code layer is empty</source>
        <translation>點代碼層為空</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="331"/>
        <source>Point code height is empty</source>
        <translation>點代碼高度為空</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="332"/>
        <source>Point code separation is empty</source>
        <translation>點代碼分隔為空</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="360"/>
        <source>The file %1 not exist</source>
        <translation>文檔%1不存在</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="365"/>
        <source>Can&apos;t open the file %1</source>
        <translation>無法打開文檔 %1</translation>
    </message>
</context>
<context>
    <name>dibSHP</name>
    <message>
        <location filename="../importshp/importshp.cpp" line="59"/>
        <source>File...</source>
        <translation>文檔...</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="67"/>
        <source>File type:</source>
        <translation>文檔類型</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="75"/>
        <source>Layer</source>
        <translation>圖層</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="56"/>
        <source>Import ESRI Shapefile</source>
        <translation>導入ESRI形狀文檔</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="68"/>
        <location filename="../importshp/importshp.cpp" line="266"/>
        <source>Unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="76"/>
        <location filename="../importshp/importshp.cpp" line="89"/>
        <location filename="../importshp/importshp.cpp" line="102"/>
        <location filename="../importshp/importshp.cpp" line="115"/>
        <source>Current</source>
        <translation>當前</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="77"/>
        <location filename="../importshp/importshp.cpp" line="90"/>
        <location filename="../importshp/importshp.cpp" line="103"/>
        <location filename="../importshp/importshp.cpp" line="116"/>
        <source>From data:</source>
        <translation>從數據：</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="88"/>
        <source>Color</source>
        <translation>顏色</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="101"/>
        <source>Line type</source>
        <translation>線條類型</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="114"/>
        <source>Width</source>
        <translation>寬度</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="127"/>
        <location filename="../importshp/importshp.cpp" line="213"/>
        <source>Point</source>
        <translation>點</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="128"/>
        <source>as Point</source>
        <translation>為點</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="129"/>
        <source>as Label:</source>
        <translation>為標籤：</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="141"/>
        <source>Accept</source>
        <translation>接受</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="142"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="167"/>
        <source>Select file</source>
        <translation>選擇文檔</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="217"/>
        <source>Point+Measure</source>
        <translation>點和測量</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="221"/>
        <source>3D Point</source>
        <translation>三維點</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="225"/>
        <source>Multi Point</source>
        <translation>多點</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="229"/>
        <source>Multi Point+Measure</source>
        <translation>多點和測量</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="233"/>
        <source>3D Multi Point</source>
        <translation>三維多點</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="237"/>
        <source>Arc</source>
        <translation>弧</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="241"/>
        <source>Arc+Measure</source>
        <translation>弧和測量</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="245"/>
        <source>3D Arc</source>
        <translation>三維弧</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="249"/>
        <source>Polygon</source>
        <translation>多邊形</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="253"/>
        <source>Polygon+Measure</source>
        <translation>多邊形及測量</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="257"/>
        <source>3D Polygon</source>
        <translation>三維多邊形</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="261"/>
        <source>Multipatch</source>
        <translation>多貼片</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="281"/>
        <source>The file %1 not have extension .shp</source>
        <translation>檔案％1並無擴展名: .shp</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="286"/>
        <source>The file %1 not exist</source>
        <translation>檔案％1不存在</translation>
    </message>
</context>
<context>
    <name>lc_Geardlg</name>
    <message>
        <location filename="../gear/gear.cpp" line="66"/>
        <source>Draw a gear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="71"/>
        <source>Number of teeth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="79"/>
        <source>Circular pitch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="87"/>
        <source>Pressure angle (deg)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="95"/>
        <source>Addendum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="103"/>
        <source>Dedendum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="111"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="114"/>
        <source>Spur</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="115"/>
        <source>Ring</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="119"/>
        <source>Accept</source>
        <translation type="unfinished">接受</translation>
    </message>
    <message>
        <location filename="../gear/gear.cpp" line="124"/>
        <source>Cancel</source>
        <translation type="unfinished">取消</translation>
    </message>
</context>
<context>
    <name>lc_Listdlg</name>
    <message>
        <location filename="../list/list.cpp" line="274"/>
        <source>List entities</source>
        <translation>實體列表</translation>
    </message>
</context>
<context>
    <name>lc_Sampledlg</name>
    <message>
        <location filename="../sample/sample.cpp" line="54"/>
        <source>Draw line</source>
        <translation>畫線</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="60"/>
        <source>Start X:</source>
        <translation>起始 X:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="66"/>
        <source>Start Y:</source>
        <translation>起始 Y:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="72"/>
        <source>End X:</source>
        <translation>終點 X:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="78"/>
        <source>End Y:</source>
        <translation>終點 Y:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="86"/>
        <source>Accept</source>
        <translation>接受</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="91"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="107"/>
        <source>Start X is empty</source>
        <translation>起點X為空</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="108"/>
        <source>Start Y is empty</source>
        <translation>起點Y為空</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="109"/>
        <source>End X is empty</source>
        <translation>終點X為空</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="110"/>
        <source>End Y is empty</source>
        <translation>終點Y為空</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="132"/>
        <source>Sample plugin</source>
        <translation>示例插件</translation>
    </message>
</context>
<context>
    <name>picPunto</name>
    <message>
        <location filename="../picfile/picfile.cpp" line="65"/>
        <source>File...</source>
        <translation type="unfinished">文檔...</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="75"/>
        <source>Scale:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="79"/>
        <source>Accept</source>
        <translation type="unfinished">接受</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="83"/>
        <source>Cancel</source>
        <translation type="unfinished">取消</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="111"/>
        <source>Select file</source>
        <translation type="unfinished">選擇文檔</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="119"/>
        <source>Scale Factor is empty or invalid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="132"/>
        <source>The file %1 not exist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="137"/>
        <source>Can&apos;t open the file %1</source>
        <translation type="unfinished">無法打開文檔 %1</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="144"/>
        <source>%1 objects imported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="166"/>
        <source>picPunto drawLine: first point is empty %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="179"/>
        <source>picPunto drawLine: next point is empty %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="258"/>
        <location filename="../picfile/picfile.cpp" line="267"/>
        <source>format error in %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>plot</name>
    <message>
        <location filename="../plotequation/plot.cpp" line="21"/>
        <location filename="../plotequation/plot.cpp" line="28"/>
        <source>Plot plugin</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>plotDialog</name>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="15"/>
        <source>Plot equation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="18"/>
        <source>This plugin allows you to plot mathematical equations.
If you don&apos;t want to use the parametric form, just leave out &quot;Equation2&quot;.
You can use pi when you need the value of pi (i.e. (3*pi)).
Use t or x in your equation as a variable/parameter.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="22"/>
        <source>Equation 1:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="23"/>
        <source>Equation 2:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="26"/>
        <source>start value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="27"/>
        <source>end value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="28"/>
        <source>step size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="32"/>
        <source>Draw</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="33"/>
        <source>Cancel</source>
        <translation type="unfinished">取消</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="59"/>
        <source>Line Segments</source>
        <comment>Plot Equation to generate RS_Line segments</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="60"/>
        <source>Polyline</source>
        <comment>Plot Equation to generate RS_Polyline</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="61"/>
        <source>SplinePoints</source>
        <comment>Plot Equation to generate 2nd spline by LC_SplinePoints</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>pointBox</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="175"/>
        <source>Layer:</source>
        <translation>層:</translation>
    </message>
</context>
<context>
    <name>textBox</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="207"/>
        <source>Style:</source>
        <translation>類型:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="208"/>
        <source>Height:</source>
        <translation>高度：</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="209"/>
        <source>Separation</source>
        <translation>分隔</translation>
    </message>
</context>
</TS>
